@@ -144,6 +144,15 @@ class menu_options:
 		w=self.tree.get_object("menu_title_font")
 		w.set_font_name(global_vars["menu_title_fontname"])
 		
+		w=self.tree.get_object("margin_top_adj")
+		w.set_value(100.0*global_vars["menu_top_margin"])
+		w=self.tree.get_object("margin_bottom_adj")
+		w.set_value(100.0*global_vars["menu_bottom_margin"])
+		w=self.tree.get_object("margin_left_adj")
+		w.set_value(100.0*global_vars["menu_left_margin"])
+		w=self.tree.get_object("margin_right_adj")
+		w.set_value(100.0*global_vars["menu_right_margin"])
+		
 		self.window.show()
 
 
@@ -250,6 +259,8 @@ class menu_options:
 		global_vars2={}
 		global_vars2["PAL"]=self.global_vars["PAL"]
 		global_vars2["with_menu"]=True
+		global_vars2["AC3_fix"]=self.global_vars["AC3_fix"]
+		global_vars2["use_ffmpeg"]=self.global_vars["use_ffmpeg"]
 		self.set_new_bg(global_vars2)
 		window=menu_preview(self.gladefile,self.structure,global_vars2)
 		window=None
@@ -334,6 +345,15 @@ class menu_options:
 		w=self.tree.get_object("menu_title_font")
 		global_vars["menu_title_fontname"]=w.get_font_name()
 		
+		w=self.tree.get_object("margin_top_adj")
+		global_vars["menu_top_margin"]=w.get_value()/100.0
+		w=self.tree.get_object("margin_bottom_adj")
+		global_vars["menu_bottom_margin"]=w.get_value()/100.0
+		w=self.tree.get_object("margin_left_adj")
+		global_vars["menu_left_margin"]=w.get_value()/100.0
+		w=self.tree.get_object("margin_right_adj")
+		global_vars["menu_right_margin"]=w.get_value()/100.0
+		
 		# repaint the used size
 		self.callback()
 
@@ -376,7 +396,7 @@ class menu_preview:
 		if global_vars.has_key("menu_sound_duration")==False:
 			global_vars["menu_sound_duration"]=1
 		clase=devede_xml_menu.xml_files(None,None,None,structure,global_vars,"","")
-		self.sf=clase.create_menu_bg(0,0)
+		self.sf=clase.create_menu_bg(0,0,0,True)
 
 		if self.sf==None:
 			devede_dialogs.show_error(gladefile,_("Can't find the menu background.\nCheck the menu options."))
