@@ -379,8 +379,8 @@ def calcula_tamano_parcial(vrate,arate,filesize,length,subs,ismpeg,isvob,cutting
 
 def calcule_menu_size(structure,sound_duration):
 
-	# each menu needs 1128 kbits/sec * sound_duration / 8
-	return (141*sound_duration)*((len(structure)+9)/10)
+	# each menu needs 2692 kbits/sec * sound_duration / 8
+	return (337*sound_duration)*((len(structure)+9)/10)
 
 
 def calcula_tamano_total(structure,sound_duration,disktype):
@@ -422,6 +422,7 @@ def load_config(global_vars):
 	home=get_home_directory()
 	global_vars["PAL"]=True
 	global_vars["multicore"]=1 # it shouldn't use multicore by default
+	global_vars["hyperthreading"]=True # by default, use hyperthreading
 
 	# TODO change to allow a windows temp directory
 
@@ -465,6 +466,11 @@ def load_config(global_vars):
 					global_vars["multicore"]=1
 				else:
 					global_vars["multicore"]=global_vars["cores"]
+			if linea[:15]=="hyperthreading:":
+				if linea[15:]=="1":
+					global_vars["hyperthreading"]=True
+				else:
+					global_vars["hyperthreading"]=False
 			if linea[:13]=="final_folder:":
 				global_vars["finalfolder"]=linea[13:]
 			if linea[:13]=="sub_language:":
@@ -486,7 +492,11 @@ def load_config(global_vars):
 					global_vars["use_ffmpeg"]=True
 				else:
 					global_vars["use_ffmpeg"]=False
-					
+			if linea[:16]=="use_ffmpeg_menu:":
+				if linea[16:]=="1":
+					global_vars["use_ffmpeg_menu"]=True
+				else:
+					global_vars["use_ffmpeg_menu"]=False
 			#if linea[:]==":":
 			#	global_vars[""]=linea[:]
 		archivo.close()
@@ -518,6 +528,10 @@ def save_config(global_vars):
 			archivo.write("video_format:ntsc\n")
 		archivo.write("temp_folder:"+global_vars["temp_folder"]+"\n")
 		archivo.write("multicore:"+str(global_vars["multicore"])+"\n")
+		if global_vars["hyperthreading"]:
+			archivo.write("hyperthreading:1\n")
+		else:
+			archivo.write("hyperthreading:0\n")
 		if global_vars["finalfolder"]!="":
 			archivo.write("final_folder:"+str(global_vars["finalfolder"])+"\n")
 		archivo.write("sub_language:"+str(global_vars["sub_language"])+"\n")
@@ -534,6 +548,10 @@ def save_config(global_vars):
 			archivo.write("use_ffmpeg:1\n")
 		else:
 			archivo.write("use_ffmpeg:0\n")
+		if global_vars["use_ffmpeg_menu"]:
+			archivo.write("use_ffmpeg_menu:1\n")
+		else:
+			archivo.write("use_ffmpeg_menu:0\n")
 		archivo.close()
 	except IOError:
 		pass
